@@ -703,8 +703,14 @@ class BIDSStatsModelsNodeOutput:
         # Create dummy contrasts as regular contrasts
         dummies = self.node.dummy_contrasts
         if dummies:
-            if 'conditionlist' in dummies:
-                conditions = set(dummies['condition_list'])
+            if {'conditions', 'condition_list'} & set(dummies):
+                warnings.warn(
+                    "Use 'Contrasts' not 'Conditions' or 'ConditionList' to specify"
+                    "DummyContrasts. Renaming to 'Contrasts' for now.")
+                dummies['contrasts'] = dummies.pop('conditions', None) or dummies.pop('condition_list', None)
+
+            if 'contrasts' in dummies:
+                conditions = set(dummies['contrasts'])
             else:
                 conditions = col_names
 
